summaryrefslogtreecommitdiffstats
path: root/third_party/sqlite/ext/fts2/fts2_tokenizer.c
diff options
context:
space:
mode:
Diffstat (limited to 'third_party/sqlite/ext/fts2/fts2_tokenizer.c')
-rw-r--r--third_party/sqlite/ext/fts2/fts2_tokenizer.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/third_party/sqlite/ext/fts2/fts2_tokenizer.c b/third_party/sqlite/ext/fts2/fts2_tokenizer.c
index 43eba11..00ed365 100644
--- a/third_party/sqlite/ext/fts2/fts2_tokenizer.c
+++ b/third_party/sqlite/ext/fts2/fts2_tokenizer.c
@@ -240,7 +240,7 @@ int registerTokenizer(
}
static
-int queryTokenizer(
+int queryFts2Tokenizer(
sqlite3 *db,
char *zName,
const sqlite3_tokenizer_module **pp
@@ -273,7 +273,7 @@ void sqlite3Fts2SimpleTokenizerModule(sqlite3_tokenizer_module const**ppModule);
** build unless SQLITE_TEST is defined.
**
** The purpose of this is to test that the fts2_tokenizer() function
** can be used as designed by the C-code in the queryTokenizer and
** registerTokenizer() functions above. These two functions are repeated
** in the README.tokenizer file as an example, so it is important to
** test them.
@@ -297,10 +297,10 @@ static void intTestFunc(
/* Test the query function */
sqlite3Fts2SimpleTokenizerModule(&p1);
- rc = queryTokenizer(db, "simple", &p2);
+ rc = queryFts2Tokenizer(db, "simple", &p2);
assert( rc==SQLITE_OK );
assert( p1==p2 );
- rc = queryTokenizer(db, "nosuchtokenizer", &p2);
+ rc = queryFts2Tokenizer(db, "nosuchtokenizer", &p2);
assert( rc==SQLITE_ERROR );
assert( p2==0 );
assert( 0==strcmp(sqlite3_errmsg(db), "unknown tokenizer: nosuchtokenizer") );
@@ -308,7 +308,7 @@ static void intTestFunc(
/* Test the storage function */
rc = registerTokenizer(db, "nosuchtokenizer", p1);
assert( rc==SQLITE_OK );
- rc = queryTokenizer(db, "nosuchtokenizer", &p2);
+ rc = queryFts2Tokenizer(db, "nosuchtokenizer", &p2);
assert( rc==SQLITE_OK );
assert( p2==p1 );
@@ -273,7 +273,7 @@ void sqlite3Fts2SimpleTokenizerModule(sqlite3_tokenizer_module const**ppModule);
**
** The purpose of this is to test that the fts2_tokenizer() function
-** can be used as designed by the C-code in the queryTokenizer and
+** can be used as designed by the C-code in the queryFts2Tokenizer and
** registerTokenizer() functions above. These two functions are repeated
** in the README.tokenizer file as an example, so it is important to